@@ -1,7 +1,7 @@
 """
 Type annotations for workdocs service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/literals/)
 
 Usage::
 
@@ -59,6 +59,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -252,6 +253,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -353,6 +355,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -460,3 +463,6 @@ PaginatorName = Literal[
     "describe_root_folders",
     "describe_users",
 ]
+RegionName = Literal[
+    "ap-northeast-1", "ap-southeast-1", "ap-southeast-2", "eu-west-1", "us-east-1", "us-west-2"
+]
